

#ifndef __IRR_C_RENDER_WINDOW_X11_H__
#define __IRR_C_RENDER_WINDOW_X11_H__



#include "IRenderWindow.h"
#include "IrrCompileConfig.h"

#ifdef _IRR_COMPILE_WITH_X11_DEVICE_

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#ifdef _IRR_LINUX_X11_VIDMODE_
#include <X11/extensions/xf86vmode.h>
#endif

namespace irr
{

namespace video
{


struct SRenderWindowLinuxHandle
{
    Window WindowId;
    Display *X11Connection;
    XVisualInfo* Visual;
};


// TODO we should be able to create a CRenderWindowWin32  from a valid WindowId
class CRenderWindowLinux : public IRenderWindow
{

public:
    /** Default constructor.
    */
    CRenderWindowLinux( Display *display, Window windowId, XVisualInfo* Visual, bool externalWindow);
    virtual ~CRenderWindowLinux();



    //!
    virtual core::dimension2d<u32> getSize() const;

    //! relative to upper-left point of screen (0/0)
    virtual core::dimension2d<u32> getPosition() const;

    virtual bool isResizable() const;

    virtual void forceDestroy();

    //! sets the caption of the window
    virtual void setWindowCaption(const wchar_t* text)  ;

    //! returns if window is active. if not, nothing need to be drawn
    virtual bool isWindowActive() const  ;

    //! returns if window has focus
    virtual bool isWindowFocused() const  ;

    //! returns if window is minimized
    virtual bool isWindowMinimized() const  ;

    virtual bool isFullscreen() const  ;

    //! Get the current color format of the window
    /** \return Color format of the window. */
    virtual video::ECOLOR_FORMAT getColorFormat() const ;

    //! Notifies the device, that it has been resized
    void OnResized();

    //! Sets if the window should be resizable in windowed mode.
    virtual void setResizable(bool resize=false)  ;

    //! Minimizes the window.
    virtual void minimizeWindow()  ;

    //! Maximizes the window.
    virtual void maximizeWindow()  ;

    //! Restores the window size.
    virtual void restoreWindow()  ;


//    virtual SRenderWindowLinuxHandle getWindowHandle() ;
    virtual void* getWindowHandle() ;

    bool switchToFullScreen(bool reset);

    // bool force
    virtual void closeWindow(bool forceDestroy) ;


//protected:
    SRenderWindowLinuxHandle VideoData;
    int screennr;
    Window WindowId;
    Display *X11Connection;
    XSetWindowAttributes attributes;
    XSizeHints* StdHints;
    XVisualInfo* visual;    //!< Contains window info

    u32 Width, Height;

		bool WindowHasFocus;
		bool WindowMinimized;

    //TODO
    bool ChangedToFullScreen;
    bool Resized;
};



}  // video
} // irr

#endif  // _IRR_COMPILE_WITH_X11_DEVICE_

#endif


#ifndef __IRR_C_RENDER_WINDOW_X11_H__
#define __IRR_C_RENDER_WINDOW_X11_H__



#include "IRenderWindow.h"
#include "IrrCompileConfig.h"

#ifdef _IRR_COMPILE_WITH_X11_DEVICE_

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#ifdef _IRR_LINUX_X11_VIDMODE_
#include <X11/extensions/xf86vmode.h>
#endif

namespace irr
{

namespace video
{

// TODO we should be able to create a CRenderWindowWin32  from a valid WindowId
class IRRLICHT_API CRenderWindowLinux : public IRenderWindow
//                                        , public video::IImagePresenter
{

public:
    /** Default constructor.
    */
//    CRenderWindowLinux(    Display *display;);
    CRenderWindowLinux( Display *display, Window windowId, XVisualInfo* Visual);
    ~CRenderWindowLinux();

//!void* windowId,
//    bool present(video::IImage* image,  core::rect<s32>* src);


    //!
    virtual core::dimension2d<u32> getSize() const;

    //! relative to upper-left point of screen (0/0)
    virtual core::dimension2d<u32> getPosition() const;

    virtual bool isResizable() const;

    virtual void forceDestroy();

    //! sets the caption of the window
    virtual void setWindowCaption(const wchar_t* text)  ;

    //! returns if window is active. if not, nothing need to be drawn
    virtual bool isWindowActive() const  ;

    //! returns if window has focus
    virtual bool isWindowFocused() const  ;

    //! returns if window is minimized
    virtual bool isWindowMinimized() const  ;

    virtual bool isFullscreen() const  ;

    //! Get the current color format of the window
    /** \return Color format of the window. */
    virtual video::ECOLOR_FORMAT getColorFormat() const ;

    //! Notifies the device, that it has been resized
    void OnResized();

    //! Sets if the window should be resizable in windowed mode.
    virtual void setResizable(bool resize=false)  ;

    //! Minimizes the window.
    virtual void minimizeWindow()  ;

    //! Maximizes the window.
    virtual void maximizeWindow()  ;

    //! Restores the window size.
    virtual void restoreWindow()  ;


    bool switchToFullScreen(bool reset);


//protected:
    int screennr;
    Window WindowId;
    Display *X11Connection;
    XSetWindowAttributes attributes;
    XSizeHints* StdHints;
    XVisualInfo* visual;    //!< Contains window info

    u32 Width, Height;

		bool WindowHasFocus;
		bool WindowMinimized;

    bool ChangedToFullScreen;
    bool Resized;
    bool ExternalWindow;
};



}  // video
} // irr

#endif  // _IRR_COMPILE_WITH_X11_DEVICE_

#endif


#ifndef __IRR_C_RENDER_WINDOW_X11_H__
#define __IRR_C_RENDER_WINDOW_X11_H__



#include "IRenderWindow.h"
#include "IrrCompileConfig.h"

#ifdef _IRR_COMPILE_WITH_X11_DEVICE_

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#ifdef _IRR_LINUX_X11_VIDMODE_
#include <X11/extensions/xf86vmode.h>
#endif

namespace irr
{

namespace video
{

// TODO we should be able to create a CRenderWindowWin32  from a valid WindowId
class IRRLICHT_API CRenderWindowLinux : public IRenderWindow
//                                        , public video::IImagePresenter
{

public:
    /** Default constructor.
    */
//    CRenderWindowLinux(    Display *display;);
    CRenderWindowLinux( Display *display, Window windowId, XVisualInfo* Visual);
    ~CRenderWindowLinux();

//!void* windowId,
//    bool present(video::IImage* image,  core::rect<s32>* src);


    //!
    virtual core::dimension2d<u32> getSize() const;

    //! relative to upper-left point of screen (0/0)
    virtual core::dimension2d<u32> getPosition() const;

    virtual bool isResizable() const;

    virtual void forceDestroy();

    //! sets the caption of the window
    virtual void setWindowCaption(const wchar_t* text)  ;

    //! returns if window is active. if not, nothing need to be drawn
    virtual bool isWindowActive() const  ;

    //! returns if window has focus
    virtual bool isWindowFocused() const  ;

    //! returns if window is minimized
    virtual bool isWindowMinimized() const  ;

    virtual bool isFullscreen() const  ;

    //! Get the current color format of the window
    /** \return Color format of the window. */
    virtual video::ECOLOR_FORMAT getColorFormat() const ;

    //! Notifies the device, that it has been resized
    void OnResized();

    //! Sets if the window should be resizable in windowed mode.
    virtual void setResizable(bool resize=false)  ;

    //! Minimizes the window.
    virtual void minimizeWindow()  ;

    //! Maximizes the window.
    virtual void maximizeWindow()  ;

    //! Restores the window size.
    virtual void restoreWindow()  ;


    bool switchToFullScreen(bool reset);


//protected:
    int screennr;
    Window WindowId;
    Display *X11Connection;
    XSetWindowAttributes attributes;
    XSizeHints* StdHints;
    XVisualInfo* visual;    //!< Contains window info

    u32 Width, Height;

		bool WindowHasFocus;
		bool WindowMinimized;

    bool ChangedToFullScreen;
    bool Resized;
    bool ExternalWindow;
};



}  // video
} // irr

#endif  // _IRR_COMPILE_WITH_X11_DEVICE_

#endif


#ifndef __IRR_C_RENDER_WINDOW_X11_H__
#define __IRR_C_RENDER_WINDOW_X11_H__



#include "IRenderWindow.h"
#include "IrrCompileConfig.h"

#ifdef _IRR_COMPILE_WITH_X11_DEVICE_

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#ifdef _IRR_LINUX_X11_VIDMODE_
#include <X11/extensions/xf86vmode.h>
#endif

namespace irr
{

namespace video
{

// TODO we should be able to create a CRenderWindowWin32  from a valid WindowId
class IRRLICHT_API CRenderWindowLinux : public IRenderWindow
//                                        , public video::IImagePresenter
{

public:
    /** Default constructor.
    */
//    CRenderWindowLinux(    Display *display;);
    CRenderWindowLinux( Display *display, Window windowId, XVisualInfo* Visual);
    ~CRenderWindowLinux();

//!void* windowId,
//    bool present(video::IImage* image,  core::rect<s32>* src);


    //!
    virtual core::dimension2d<u32> getSize() const;

    //! relative to upper-left point of screen (0/0)
    virtual core::dimension2d<u32> getPosition() const;

    virtual bool isResizable() const;

    virtual void forceDestroy();

    //! sets the caption of the window
    virtual void setWindowCaption(const wchar_t* text)  ;

    //! returns if window is active. if not, nothing need to be drawn
    virtual bool isWindowActive() const  ;

    //! returns if window has focus
    virtual bool isWindowFocused() const  ;

    //! returns if window is minimized
    virtual bool isWindowMinimized() const  ;

    virtual bool isFullscreen() const  ;

    //! Get the current color format of the window
    /** \return Color format of the window. */
    virtual video::ECOLOR_FORMAT getColorFormat() const ;

    //! Notifies the device, that it has been resized
    void OnResized();

    //! Sets if the window should be resizable in windowed mode.
    virtual void setResizable(bool resize=false)  ;

    //! Minimizes the window.
    virtual void minimizeWindow()  ;

    //! Maximizes the window.
    virtual void maximizeWindow()  ;

    //! Restores the window size.
    virtual void restoreWindow()  ;


    bool switchToFullScreen(bool reset);


//protected:
    int screennr;
    Window WindowId;
    Display *X11Connection;
    XSetWindowAttributes attributes;
    XSizeHints* StdHints;
    XVisualInfo* visual;    //!< Contains window info

    u32 Width, Height;

		bool WindowHasFocus;
		bool WindowMinimized;

    bool ChangedToFullScreen;
    bool Resized;
    bool ExternalWindow;
};



}  // video
} // irr

#endif  // _IRR_COMPILE_WITH_X11_DEVICE_

#endif


#ifndef __IRR_C_RENDER_WINDOW_X11_H__
#define __IRR_C_RENDER_WINDOW_X11_H__



#include "IRenderWindow.h"
#include "IrrCompileConfig.h"

#ifdef _IRR_COMPILE_WITH_X11_DEVICE_

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#ifdef _IRR_LINUX_X11_VIDMODE_
#include <X11/extensions/xf86vmode.h>
#endif

namespace irr
{

namespace video
{

// TODO we should be able to create a CRenderWindowWin32  from a valid WindowId
class IRRLICHT_API CRenderWindowLinux : public IRenderWindow
//                                        , public video::IImagePresenter
{

public:
    /** Default constructor.
    */
//    CRenderWindowLinux(    Display *display;);
    CRenderWindowLinux( Display *display, Window windowId, XVisualInfo* Visual);
    ~CRenderWindowLinux();

//!void* windowId,
//    bool present(video::IImage* image,  core::rect<s32>* src);


    //!
    virtual core::dimension2d<u32> getSize() const;

    //! relative to upper-left point of screen (0/0)
    virtual core::dimension2d<u32> getPosition() const;

    virtual bool isResizable() const;

    virtual void forceDestroy();

    //! sets the caption of the window
    virtual void setWindowCaption(const wchar_t* text)  ;

    //! returns if window is active. if not, nothing need to be drawn
    virtual bool isWindowActive() const  ;

    //! returns if window has focus
    virtual bool isWindowFocused() const  ;

    //! returns if window is minimized
    virtual bool isWindowMinimized() const  ;

    virtual bool isFullscreen() const  ;

    //! Get the current color format of the window
    /** \return Color format of the window. */
    virtual video::ECOLOR_FORMAT getColorFormat() const ;

    //! Notifies the device, that it has been resized
    void OnResized();

    //! Sets if the window should be resizable in windowed mode.
    virtual void setResizable(bool resize=false)  ;

    //! Minimizes the window.
    virtual void minimizeWindow()  ;

    //! Maximizes the window.
    virtual void maximizeWindow()  ;

    //! Restores the window size.
    virtual void restoreWindow()  ;


    bool switchToFullScreen(bool reset);


//protected:
    int screennr;
    Window WindowId;
    Display *X11Connection;
    XSetWindowAttributes attributes;
    XSizeHints* StdHints;
    XVisualInfo* visual;    //!< Contains window info

    u32 Width, Height;

		bool WindowHasFocus;
		bool WindowMinimized;

    bool ChangedToFullScreen;
    bool Resized;
    bool ExternalWindow;
};



}  // video
} // irr

#endif  // _IRR_COMPILE_WITH_X11_DEVICE_

#endif


#ifndef __IRR_C_RENDER_WINDOW_X11_H__
#define __IRR_C_RENDER_WINDOW_X11_H__



#include "IRenderWindow.h"
#include "IrrCompileConfig.h"

#ifdef _IRR_COMPILE_WITH_X11_DEVICE_

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>
#ifdef _IRR_LINUX_X11_VIDMODE_
#include <X11/extensions/xf86vmode.h>
#endif

namespace irr
{

namespace video
{

// TODO we should be able to create a CRenderWindowWin32  from a valid WindowId
class IRRLICHT_API CRenderWindowLinux : public IRenderWindow
//                                        , public video::IImagePresenter
{

public:
    /** Default constructor.
    */
//    CRenderWindowLinux(    Display *display;);
    CRenderWindowLinux( Display *display, Window windowId, XVisualInfo* Visual);
    ~CRenderWindowLinux();

//!void* windowId,
//    bool present(video::IImage* image,  core::rect<s32>* src);


    //!
    virtual core::dimension2d<u32> getSize() const;

    //! relative to upper-left point of screen (0/0)
    virtual core::dimension2d<u32> getPosition() const;

    virtual bool isResizable() const;

    virtual void forceDestroy();

    //! sets the caption of the window
    virtual void setWindowCaption(const wchar_t* text)  ;

    //! returns if window is active. if not, nothing need to be drawn
    virtual bool isWindowActive() const  ;

    //! returns if window has focus
    virtual bool isWindowFocused() const  ;

    //! returns if window is minimized
    virtual bool isWindowMinimized() const  ;

    virtual bool isFullscreen() const  ;

    //! Get the current color format of the window
    /** \return Color format of the window. */
    virtual video::ECOLOR_FORMAT getColorFormat() const ;

    //! Notifies the device, that it has been resized
    void OnResized();

    //! Sets if the window should be resizable in windowed mode.
    virtual void setResizable(bool resize=false)  ;

    //! Minimizes the window.
    virtual void minimizeWindow()  ;

    //! Maximizes the window.
    virtual void maximizeWindow()  ;

    //! Restores the window size.
    virtual void restoreWindow()  ;


    bool switchToFullScreen(bool reset);


//protected:
    int screennr;
    Window WindowId;
    Display *X11Connection;
    XSetWindowAttributes attributes;
    XSizeHints* StdHints;
    XVisualInfo* visual;    //!< Contains window info

    u32 Width, Height;

		bool WindowHasFocus;
		bool WindowMinimized;

    bool ChangedToFullScreen;
    bool Resized;
    bool ExternalWindow;
};



}  // video
} // irr

#endif  // _IRR_COMPILE_WITH_X11_DEVICE_

#endif
